# Contributing to `goatpie`

Thank you very much for considering to help us improve this project by adding a feature, fixing a bug or proposing other useful changes to it.

## Code of Conduct

This project and everyone participating in it is governed by our [Code of Conduct](CODE_OF_CONDUCT.md). By participating, you are expected to uphold this code. Please report unacceptable behavior to [webmaster@refbw.de](mailto:webmaster@refbw.de).
